.dirty-indicator{
    .fa();
    width:20px;
}
.dirty-indicator-dirty{
    .dirty-indicator();
}

.dirty-indicator-clean{
    .dirty-indicator();
    &:before{
        .icon(@fa-var-check);
    }
}

#filename {
    font-size: 16pt;
    display: table;
    padding: 0px 5px;
}

#current-mode{
    padding-left: 5px;
    padding-right: 5px;
}

#texteditor-backdrop {
    padding-top: @page-header-padding;
    padding-bottom: @page-header-padding;
    
    @media not print{
        background-color: @page-backdrop-color;
    }

    #texteditor-container {
        .CodeMirror-gutter, .CodeMirror-gutters {
            @media print {
                background-color: @body-bg;
            }
            @media not print {
                background-color: @page-color;
            }
        }

        @media not print{
            padding: 0px;
            background-color :  @page-color;
            .box-shadow(@global-shadow);
        }
    }
}

.CodeMirror-dialog {
  background-color: @page-color;
}
