div.text_cell {
    .hbox();
}
@media (max-width: @screen-xs-min) {
    // remove prompt indentation on small screens
    div.text_cell > div.prompt {
        display: none;
    }
}

div.text_cell_render {
    /*font-family: "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;*/
    outline: none;
    resize: none;
    width:  inherit;
    border-style: none;
    padding: 0.5em 0.5em 0.5em @code_padding;
    color: @text-color;
    .border-box-sizing();
}

a.anchor-link:link {
  text-decoration: none;
  padding: 0px 20px;
  visibility: hidden;
}

h1,h2,h3,h4,h5,h6 {
    &:hover .anchor-link {
        visibility: visible;
    }
}

.text_cell.rendered .input_area {
    display: none;
}

.text_cell.rendered .rendered_html {
    overflow-x: auto;
    
    // Content in the y direction should cause the rendered content to grow,
    // the overflow-x: auto causes chrome to assume the same of y, so we need
    // to tell it explicitly otherwise.
    overflow-y: hidden;
}

.text_cell.rendered .rendered_html {
	tr, th, td {
		max-width: none;
	}
}

.text_cell.unrendered .text_cell_render {
    display:none;
}

.text_cell .dropzone .input_area {
  border: 2px dashed #bababa;
  margin: -1px;
}

.cm-header-1,
.cm-header-2,
.cm-header-3,
.cm-header-4,
.cm-header-5,
.cm-header-6 {
    font-weight: bold;
    font-family: @font-family-sans-serif;
}

.cm-header-1 { font-size: 185.7%; }
.cm-header-2 { font-size: 157.1%; }
.cm-header-3 { font-size: 128.6%; }
.cm-header-4 { font-size: 110%; }
.cm-header-5 {
    font-size: 100%;
    font-style: italic;
}
.cm-header-6 {
    font-size: 100%;
    font-style: italic;
}
