.quickhelp {
    .hbox();
    line-height: 1.8em;
}
.shortcut_key {
    display: inline-block;
    width: 21ex;
    text-align: right;
    font-family: @font-family-monospace;
}

.shortcut_descr {
    display: inline-block;
    .box-flex1();
}
