// Mixin CSS classes

.border-box-sizing {
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

.corner-all {
    border-radius: @border-radius-base;
}

.border-radius(@radius) {
  border-radius: @radius;
}

.no-padding {
    padding: 0px;
}
