#kernel_logo_widget {
    .current_kernel_logo {
        display: none;
        .navbar-vertical-align(32px);
        width: 32px;
        height: 32px;
    }
}

[dir="rtl"] #kernel_logo_widget {
    .pull-left();
}
