

#menubar {

  .border-box-sizing();
  margin-top: 1px;

  .navbar {
    border-top: 1px;
    border-radius: 0px 0px @border-radius-base @border-radius-base;
    margin-bottom: 0px;
  }
  
  .navbar-toggle {
    float: left;
    padding-top:7px;
    padding-bottom:7px;
    border:none;
  }
  .navbar-collapse {
    clear: left;
  }
  
}

[dir="rtl"] #menubar {
    .navbar-toggle {
        float: right;
  }
}

[dir="rtl"] #menubar {
    .navbar-collapse {
        clear: right;
   }
    .navbar-nav {
        float : right;
    }
    .nav {
        padding-right : 0px;
    }
     .navbar-nav > li {
        float: right;
    }
    .navbar-right {
        float : left !important;
    }
}

ul.dropdown-menu:focus

[dir="rtl"] ul.dropdown-menu {
    text-align: right;
    left : auto;
}

[dir="rtl"] ul#new-menu.dropdown-menu {
    right : auto;
    left: 0;
}
.nav-wrapper {
  border-bottom: 1px solid @navbar-default-border;
}

i.menu-icon {
  // add padding to account for float-right
  padding-top: 4px;
}

[dir="rtl"] i.menu-icon.pull-right {
    .pull-left();
}

ul.dropdown-menu li a.menu-shortcut-container {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: flex-end;
}

ul#help_menu li a{
    overflow: hidden;
    padding-right: 2.2em;
    i {
        margin-right: -1.2em;
    }
}

[dir="rtl"] ul#help_menu li a{
    padding-left : 2.2em;
    i {
        margin-right: 0;
        margin-left : -1.2em;
    }
    
    i.pull-right {
        .pull-left();
    }
}



// Make sub menus work in BS3.
// Credit: http://www.bootply.com/86684
.dropdown-submenu {
    position: relative;
}

.dropdown-submenu>.dropdown-menu {
    top: 0;
    left: 100%;
    margin-top: -6px;
    margin-left: -1px;
}

[dir="rtl"] .dropdown-submenu>.dropdown-menu {
    right:100%;
    margin-right: -1px; 
}

// arrow that indicate presence of submenu
.dropdown-submenu:hover>.dropdown-menu {
    display: block;
}

.dropdown-submenu>a:after {
    .fa();
    display: block;
    content: @fa-var-caret-right;
    float: right;
    color: @dropdown-link-color;
    margin-top: 2px;
    margin-right: -10px;
}

[dir="rtl"] .dropdown-submenu>a:after {
    float: left;
    content: @fa-var-caret-left;
    margin-right : 0;
    margin-left : -10px;
}

.dropdown-submenu:hover>a:after {
    color: @dropdown-link-hover-color;
}

.dropdown-submenu.pull-left {
    float: none;
}

.dropdown-submenu.pull-left>.dropdown-menu {
    left: -100%;
    margin-left: 10px;
}

.action {
    
}

.kb {
    color: darkgray;
    margin-left: 10px;
    text-transform: capitalize;
    kbd {
        white-space: nowrap;
    }
}

//end submenu
