/* We need an invisible input field on top of the sentense*/
/* "Drag file onto the list ..." */

.alternate_upload {
    background-color:none;
    display: inline;

    &.form
    {
        padding: 0;
        margin:0;
    }

    input.fileinput
    {
        position: absolute;

        display: block;
        width: 100%;
        height: 100%;
        overflow: hidden;
        cursor: pointer;
        opacity: 0;
        z-index: 2;
    }

    .btn-xs > input.fileinput {
        margin: -@padding-xs-vertical -@padding-xs-horizontal;
    }

    .btn-upload {
        position: relative;
        height: @btn_mini_height;
    }
}

::-webkit-file-upload-button { cursor:pointer; }
