div.typeahead__container {
  font: revert;
}

ul.typeahead__list i {
    width: 18px;
}

ul.typeahead__list {
  max-height: 80vh;
  overflow:auto;

    & > li > a {
        /** Firefox bug **/
        /* see https://github.com/jupyter/notebook/issues/559 */
        white-space: normal;
    }
}

ul.typeahead__list & > li > a.pull-right {
    .pull-left();
}

[dir="rtl"] .typeahead__list {
    text-align : right;
}

.cmd-palette {
  & .modal-body{
    padding: 7px;
  }
  
  & form {
    background: white;
  }
  
  & input {
    outline:none;
  }
}

.no-shortcut{
    min-width: 20px;
    color: transparent;
}

[dir="rtl"] .no-shortcut.pull-right{
    .pull-left();
}

[dir="rtl"] .command-shortcut.pull-right{
    .pull-left();
}

.command-shortcut:before{
    content:"(command mode)";
    padding-right:3px;
    color:@gray-light;
}

.edit-shortcut:before{
    content:"(edit)";
    padding-right:3px;
    color:@gray-light;
}

[dir="rtl"] .edit-shortcut.pull-right {
    .pull-left();
}
