// Custom styles for login.html
.center-nav {
  display: inline-block;
  // pull the lower margin back
  margin-bottom: -4px;
}

[dir="rtl"] .center-nav {
    form.pull-left {
        .pull-right();
    }
    .navbar-text {
        float: right;
    }
}

[dir="rtl"] .navbar-inner {
    text-align: right;
}

[dir="rtl"] div.text-left {
    .text-right();
}
