/* CSS for the cell toolbar */
@celltoolbar-height: 29px;

.celltoolbar {
    border: thin solid #CFCFCF;
    border-bottom: none;
    background : #EEE;
    border-radius : @border-radius-base @border-radius-base 0px 0px;
    width:100%;
    -webkit-box-pack: end;
    height: @celltoolbar-height;
    padding-right: 4px;
    .hbox();
    .end();
    // safari fix, we cannot use -webkit-flex on hbox
    // and vbox either or all css get borked
    // cf https://github.com/jupyter/nbgrader/issues/394
    display: -webkit-flex;
    @media print{
        display: none;
    }
}


.ctb_hideshow {
    display:none;
    vertical-align:bottom;
}

/* ctb_show is added to the ctb_hideshow div to show the cell toolbar.
   Cell toolbars are only shown when the ctb_global_show class is also set.
*/
.ctb_global_show .ctb_show.ctb_hideshow {
    display: block;
}

.ctb_global_show .ctb_show + .input_area,
.ctb_global_show .ctb_show + div.text_cell_input,
.ctb_global_show .ctb_show ~ div.text_cell_render {
    border-top-right-radius: 0px;
    border-top-left-radius: 0px;
}

.ctb_global_show .ctb_show ~ div.text_cell_render {
    // add border to rendered markdown cells
    border: @border_width solid @light_border_color;
}

.celltoolbar {
    font-size: 87%;
    padding-top: 3px;
}

.celltoolbar select {
    .form-control();
    .input-sm();
    // undo some of the sizing caused by the above mixins
    width: inherit;
    font-size: inherit;
    height: 22px;
    padding: 0px;
    
    display: inline-block;

}

.celltoolbar label {
    margin-left: 5px;
    margin-right: 5px;
}
