.modal .modal-body {
  
  .rename-message {
    
  }
  .move-path {
    display: flex;
    flex-direction: row;
    justify-content: space;
    align-items: center;
    
    .server-root {
      padding-right: 20px;
    }
    .path-input {
      flex: 1;
    }
  }
}
