@media (max-width: @screen-xs-max) {
    // remove bootstrap-responsive's body padding on small screens
    .notebook_app {
        padding-left: 0px;
        padding-right: 0px;
    }
}

#ipython-main-app {
    .border-box-sizing();
    height: 100%;
}

div#notebook_panel {
    margin: 0px;
    padding: 0px;
    .border-box-sizing();
    height: 100%;
}

div#notebook {
    font-size: @notebook_font_size;
    line-height: @notebook_line_height;
    overflow-y: hidden;
    overflow-x: auto;
    width: 100%;
    /* This spaces the page away from the edge of the notebook area */
    padding-top: @page-header-padding;
    padding-bottom: @page-header-padding;
    margin: 0px;
    outline: none;
    .border-box-sizing();
    min-height: 100%;
}

#notebook-container{
    @media not print{
        padding: @page-padding;
        background-color :  @page-color;
        min-height: @page-min-height;
        .box-shadow(@global-shadow);
    }
    @media print {
        width: 100%;
    }
}

div.ui-widget-content {
    border: 1px solid @border_color;
    outline: none;
}

pre.dialog {
    background-color: @cell_background;
    border: 1px solid #ddd;
    .corner-all;
    padding: 0.4em;
    padding-left: 2em;
}

p.dialog {
    padding : 0.2em;
}

/* Word-wrap output correctly.  This is the CSS3 spelling, though Firefox seems
   to not honor it correctly.  Webkit browsers (Chrome, rekonq, Safari) do.
 */
pre, code, kbd, samp { white-space: pre-wrap; }

#fonttest {
    font-family: @font-family-monospace;
}

p {
    margin-bottom:0;
}

.end_space {
    min-height: 100px;
    transition: height .2s ease;
}

.notebook_app > #header {
    .box-shadow(@global-shadow);
}

.notebook_app{
    @media not print {
        background-color: @page-backdrop-color;
    }
}

kbd {
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    margin: 2px;
    padding-left: 2px;
    padding-right: 2px;
    padding-top: 1px;
    padding-bottom: 1px;
}

.jupyter-keybindings {
    padding: 1px;
    line-height: 24px;
    border-bottom: 1px solid gray;
}

.jupyter-keybindings input {
    margin: 0;
    padding: 0;
    border: none;
}

.jupyter-keybindings i {
    padding: 6px;
}

.well code {
    background-color: lighten(@cell_background, 5%);
    border-color: @border_color;
    border-width: @border_width;
    border-style: solid;
    padding: 2px;
    padding-top: 1px;
    padding-bottom: 1px;
}
